@@ -378,12 +378,7 @@ class GitHubDriver extends VcsDriver
                         return $this->attemptCloneFallback();
                     }
 
-                    $rateLimited = false;
-                    foreach ($e->getHeaders() as $header) {
-                        if (preg_match('{^X-RateLimit-Remaining: *0$}i', trim($header))) {
-                            $rateLimited = true;
-                        }
-                    }
+                    $rateLimited = $githubUtil->isRateLimited($e->getHeaders());
 
                     if (!$this->io->hasAuthentication($this->originUrl)) {
                         if (!$this->io->isInteractive()) {
@@ -397,7 +392,7 @@ class GitHubDriver extends VcsDriver
                     }
 
                     if ($rateLimited) {
-                        $rateLimit = $this->getRateLimit($e->getHeaders());
+                        $rateLimit = $githubUtil->getRateLimit($e->getHeaders());
                         $this->io->writeError(sprintf(
                             '<error>GitHub API limit (%d calls/hr) is exhausted. You are already authorized so you have to wait until %s before doing more requests</error>',
                             $rateLimit['limit'],
@@ -413,39 +408,6 @@ class GitHubDriver extends VcsDriver
         }
     }
 
-    /**
-     * Extract ratelimit from response.
-     *
-     * @param array $headers Headers from Composer\Downloader\TransportException.
-     *
-     * @return array Associative array with the keys limit and reset.
-     */
-    protected function getRateLimit(array $headers)
-    {
-        $rateLimit = array(
-            'limit' => '?',
-            'reset' => '?',
-        );
-
-        foreach ($headers as $header) {
-            $header = trim($header);
-            if (false === strpos($header, 'X-RateLimit-')) {
-                continue;
-            }
-            list($type, $value) = explode(':', $header, 2);
-            switch ($type) {
-                case 'X-RateLimit-Limit':
-                    $rateLimit['limit'] = (int) trim($value);
-                    break;
-                case 'X-RateLimit-Reset':
-                    $rateLimit['reset'] = date('Y-m-d H:i:s', (int) trim($value));
-                    break;
-            }
-        }
-
-        return $rateLimit;
-    }
-
     /**
      * Fetch root identifier from GitHub
      *
